@@ -11,23 +11,30 @@
 
 namespace Symfony\Component\Security\Acl\Tests\Voter;
 
+use PHPUnit\Framework\TestCase;
 use Symfony\Component\Security\Acl\Domain\ObjectIdentity;
 use Symfony\Component\Security\Acl\Domain\RoleSecurityIdentity;
 use Symfony\Component\Security\Acl\Domain\UserSecurityIdentity;
 use Symfony\Component\Security\Acl\Exception\AclNotFoundException;
 use Symfony\Component\Security\Acl\Exception\NoAceFoundException;
+use Symfony\Component\Security\Acl\Model\AclProviderInterface;
+use Symfony\Component\Security\Acl\Model\ObjectIdentityRetrievalStrategyInterface;
+use Symfony\Component\Security\Acl\Model\SecurityIdentityRetrievalStrategyInterface;
+use Symfony\Component\Security\Acl\Permission\PermissionMapInterface;
+use Symfony\Component\Security\Acl\Tests\Fixtures\SerializableAclInterface;
 use Symfony\Component\Security\Acl\Voter\AclVoter;
 use Symfony\Component\Security\Acl\Voter\FieldVote;
+use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
 use Symfony\Component\Security\Core\Authorization\Voter\VoterInterface;
 
-class AclVoterTest extends \PHPUnit\Framework\TestCase
+class AclVoterTest extends TestCase
 {
     /**
      * @dataProvider getSupportsAttributeTests
      */
     public function testSupportsAttribute($attribute, $supported)
     {
-        list($voter, , $permissionMap) = $this->getVoter(true, false);
+        [$voter, , $permissionMap] = $this->getVoter(true, false);
 
         $permissionMap
             ->expects($this->once())
@@ -44,7 +51,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
      */
     public function testSupportsAttributeNonString($attribute)
     {
-        list($voter) = $this->getVoter(true, false);
+        [$voter] = $this->getVoter(true, false);
 
         $this->assertFalse($voter->supportsAttribute($attribute));
     }
@@ -72,7 +79,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
      */
     public function testSupportsClass($class)
     {
-        list($voter) = $this->getVoter();
+        [$voter] = $this->getVoter();
 
         $this->assertTrue($voter->supportsClass($class));
     }
@@ -88,7 +95,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
 
     public function testVote()
     {
-        list($voter, , $permissionMap) = $this->getVoter();
+        [$voter, , $permissionMap] = $this->getVoter();
         $permissionMap
             ->expects($this->atLeastOnce())
             ->method('getMasks')
@@ -103,7 +110,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
      */
     public function testVoteWhenNoObjectIsPassed($allowIfObjectIdentityUnavailable)
     {
-        list($voter, , $permissionMap) = $this->getVoter($allowIfObjectIdentityUnavailable);
+        [$voter, , $permissionMap] = $this->getVoter($allowIfObjectIdentityUnavailable);
         $permissionMap
             ->expects($this->once())
             ->method('getMasks')
@@ -124,7 +131,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
      */
     public function testVoteWhenOidStrategyReturnsNull($allowIfUnavailable)
     {
-        list($voter, , $permissionMap, $oidStrategy) = $this->getVoter($allowIfUnavailable);
+        [$voter, , $permissionMap, $oidStrategy] = $this->getVoter($allowIfUnavailable);
         $permissionMap
             ->expects($this->once())
             ->method('getMasks')
@@ -153,7 +160,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
 
     public function testVoteNoAclFound()
     {
-        list($voter, $provider, $permissionMap, $oidStrategy, $sidStrategy) = $this->getVoter();
+        [$voter, $provider, $permissionMap, $oidStrategy, $sidStrategy] = $this->getVoter();
 
         $permissionMap
             ->expects($this->once())
@@ -188,7 +195,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
      */
     public function testVoteGrantsAccess($grant)
     {
-        list($voter, $provider, $permissionMap, $oidStrategy, $sidStrategy) = $this->getVoter();
+        [$voter, $provider, $permissionMap, $oidStrategy, $sidStrategy] = $this->getVoter();
 
         $permissionMap
             ->expects($this->once())
@@ -213,7 +220,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
             ->expects($this->once())
             ->method('findAcl')
             ->with($this->equalTo($oid), $this->equalTo($sids))
-            ->willReturn($acl = $this->createMock('Symfony\Component\Security\Acl\Model\AclInterface'))
+            ->willReturn($acl = $this->createMock(SerializableAclInterface::class))
         ;
 
         $acl
@@ -234,7 +241,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
 
     public function testVoteNoAceFound()
     {
-        list($voter, $provider, $permissionMap, $oidStrategy, $sidStrategy) = $this->getVoter();
+        [$voter, $provider, $permissionMap, $oidStrategy, $sidStrategy] = $this->getVoter();
 
         $permissionMap
             ->expects($this->once())
@@ -259,7 +266,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
             ->expects($this->once())
             ->method('findAcl')
             ->with($this->equalTo($oid), $this->equalTo($sids))
-            ->willReturn($acl = $this->createMock('Symfony\Component\Security\Acl\Model\AclInterface'))
+            ->willReturn($acl = $this->createMock(SerializableAclInterface::class))
         ;
 
         $acl
@@ -277,7 +284,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
      */
     public function testVoteGrantsFieldAccess($grant)
     {
-        list($voter, $provider, $permissionMap, $oidStrategy, $sidStrategy) = $this->getVoter();
+        [$voter, $provider, $permissionMap, $oidStrategy, $sidStrategy] = $this->getVoter();
 
         $permissionMap
             ->expects($this->once())
@@ -302,7 +309,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
             ->expects($this->once())
             ->method('findAcl')
             ->with($this->equalTo($oid), $this->equalTo($sids))
-            ->willReturn($acl = $this->createMock('Symfony\Component\Security\Acl\Model\AclInterface'))
+            ->willReturn($acl = $this->createMock(SerializableAclInterface::class))
         ;
 
         $acl
@@ -323,7 +330,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
 
     public function testVoteNoFieldAceFound()
     {
-        list($voter, $provider, $permissionMap, $oidStrategy, $sidStrategy) = $this->getVoter();
+        [$voter, $provider, $permissionMap, $oidStrategy, $sidStrategy] = $this->getVoter();
 
         $permissionMap
             ->expects($this->once())
@@ -348,7 +355,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
             ->expects($this->once())
             ->method('findAcl')
             ->with($this->equalTo($oid), $this->equalTo($sids))
-            ->willReturn($acl = $this->createMock('Symfony\Component\Security\Acl\Model\AclInterface'))
+            ->willReturn($acl = $this->createMock(SerializableAclInterface::class))
         ;
 
         $acl
@@ -363,7 +370,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
 
     public function testWhenReceivingAnObjectIdentityInterfaceWeDontRetrieveANewObjectIdentity()
     {
-        list($voter, $provider, $permissionMap, $oidStrategy, $sidStrategy) = $this->getVoter();
+        [$voter, $provider, $permissionMap, $oidStrategy, $sidStrategy] = $this->getVoter();
 
         $oid = new ObjectIdentity('someID', 'someType');
 
@@ -389,7 +396,7 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
             ->expects($this->once())
             ->method('findAcl')
             ->with($this->equalTo($oid), $this->equalTo($sids))
-            ->willReturn($acl = $this->createMock('Symfony\Component\Security\Acl\Model\AclInterface'))
+            ->willReturn($acl = $this->createMock(SerializableAclInterface::class))
         ;
 
         $acl
@@ -404,15 +411,15 @@ class AclVoterTest extends \PHPUnit\Framework\TestCase
 
     protected function getToken()
     {
-        return $this->createMock('Symfony\Component\Security\Core\Authentication\Token\TokenInterface');
+        return $this->createMock(TokenInterface::class);
     }
 
     protected function getVoter($allowIfObjectIdentityUnavailable = true, $alwaysContains = true)
     {
-        $provider = $this->createMock('Symfony\Component\Security\Acl\Model\AclProviderInterface');
-        $permissionMap = $this->createMock('Symfony\Component\Security\Acl\Permission\PermissionMapInterface');
-        $oidStrategy = $this->createMock('Symfony\Component\Security\Acl\Model\ObjectIdentityRetrievalStrategyInterface');
-        $sidStrategy = $this->createMock('Symfony\Component\Security\Acl\Model\SecurityIdentityRetrievalStrategyInterface');
+        $provider = $this->createMock(AclProviderInterface::class);
+        $permissionMap = $this->createMock(PermissionMapInterface::class);
+        $oidStrategy = $this->createMock(ObjectIdentityRetrievalStrategyInterface::class);
+        $sidStrategy = $this->createMock(SecurityIdentityRetrievalStrategyInterface::class);
 
         if ($alwaysContains) {
             $permissionMap
